@@ -23,7 +23,7 @@
  */
 
 /*
- * cfs ccat - 1.2
+ * cfs ccat - 1.3
  */
 #include <stdio.h>
 #include <rpc/rpc.h>
@@ -66,7 +66,8 @@ main(argc,argv)
 	int i;
 	char *buf[8192];
 	int ciph=CFS_STD_DES;
-	
+
+	fprintf(stderr,"WARNING: ccat works only on old format CFS files\n");
 	while (--argc && (**++argv == '-')) {
 		for (flg= ++*argv; *flg; ++flg)
 			switch (*flg) {
@@ -91,7 +92,7 @@ main(argc,argv)
 	}
 	strcpy(pword,pw);
 	k.cipher=ciph;
-	if (pwcrunch(pw,&k)!=0) {
+	if (old_pwcrunch(pw,&k)!=0) {
 		fprintf(stderr,"Invalid key\n");
 		exit(1);
 	}
