@@ -37,7 +37,7 @@
 static long	ip_low();
 static long	ip_high();
 static void	fp();
-static void	key_setup();
+void	des_key_setup();
 
 /*
  *	Tables for Combined S and P Boxes
@@ -133,8 +133,9 @@ static long  s7p[] = {
 
 /*
  *	DES electronic codebook encryption of one block
+ *	 (quick version)
  */
-block_cipher(short_key, text, decrypting)
+q_block_cipher(short_key, text, decrypting)
 char short_key[8];
 char text[8];
 int decrypting;
@@ -160,7 +161,7 @@ int decrypting;
 	if (k<0) {
 		k= lk = (lk+1)%4;
 		bcopy(short_key,lastkey[k],8);
-		key_setup(short_key, expanded_key[k]);
+		des_key_setup(short_key, expanded_key[k]);
 	}
 	key = expanded_key[k];
 	left = ip_low(text);
@@ -195,6 +196,54 @@ int decrypting;
 	fp(left, right, text);
 }
 
+/*
+ *	DES electronic codebook encryption of one block
+ *	 (expanded key version)
+ */
+des_block_cipher(expanded_key, text, decrypting)
+char expanded_key[8];
+char text[8];
+int decrypting;
+{
+	register char *key;
+	register long temp;
+	register long left, right;
+	register i;
+	register key_offset;
+
+	key = expanded_key;
+	left = ip_low(text);
+	right = ip_high(text);
+	if (decrypting) {
+		key_offset = 16 - 8;
+		key = key + 128 - 8;
+	} else
+		key_offset = 0 - 8;
+	for (i = 0; i < 16; i++) {
+		temp = (right << 1) | ((right >> 31) & 1);
+		left ^= s0p[(temp         & 0x3f) ^ key[0]]
+		      ^ s1p[((temp >>  4) & 0x3f) ^ key[1]]
+		      ^ s2p[((temp >>  8) & 0x3f) ^ key[2]]
+		      ^ s3p[((temp >> 12) & 0x3f) ^ key[3]]
+		      ^ s4p[((temp >> 16) & 0x3f) ^ key[4]]
+		      ^ s5p[((temp >> 20) & 0x3f) ^ key[5]]
+		      ^ s6p[((temp >> 24) & 0x3f) ^ key[6]];
+		temp = ((right & 1) << 5) | ((right >> 27) & 0x1f);
+		left ^= s7p[temp ^ key[7]];
+		temp = left;
+		left = right;
+		right = temp;
+		key -= key_offset;
+	}
+	temp = left;
+	left = right;
+	right = temp;
+	/*
+	 *	standard final permutation (IPI)
+	 */
+	fp(left, right, text);
+}
+
 /*
  *	Final Permutation
  */
@@ -499,8 +548,8 @@ register char block[8];
  *	Key set-up
  */
 
-static void
-key_setup(key, subkeys)
+void
+des_key_setup(key, subkeys)
 char key[8];
 char *subkeys;
 {
@@ -929,9 +978,9 @@ key_crunch(buffer, size, key)
     for (i = 0; i < size; i++) {
         key[(i & 7)] ^= buffer[i];
         if ((i & 7) == 7)
-            block_cipher(s.key, key, 0);
+            q_block_cipher(s.key, key, 0);
     }
-    block_cipher(s.key, key, 0);
+    q_block_cipher(s.key, key, 0);
 }
 
 
